pub struct FulfillmentOrderItem {
Show 14 fields pub seller_sku: String, pub seller_fulfillment_order_item_id: String, pub quantity: i32, pub gift_message: Option<String>, pub displayable_comment: Option<String>, pub fulfillment_network_sku: Option<String>, pub order_item_disposition: Option<String>, pub cancelled_quantity: i32, pub unfulfillable_quantity: i32, pub estimated_ship_date: Option<String>, pub estimated_arrival_date: Option<String>, pub per_unit_price: Option<Box<Money>>, pub per_unit_tax: Option<Box<Money>>, pub per_unit_declared_value: Option<Box<Money>>,
}
FulfillmentOrderItem : Item information for a fulfillment order.

Fields

seller_sku: String

The seller SKU of the item.

seller_fulfillment_order_item_id: String

A fulfillment order item identifier submitted with a call to the createFulfillmentOrder operation.

quantity: i32

The item quantity.

gift_message: Option<String>

A message to the gift recipient, if applicable.

displayable_comment: Option<String>

Item-specific text that displays in recipient-facing materials such as the outbound shipment packing slip.

fulfillment_network_sku: Option<String>

Amazon’s fulfillment network SKU of the item.

order_item_disposition: Option<String>

Indicates whether the item is sellable or unsellable.

cancelled_quantity: i32

The item quantity.

unfulfillable_quantity: i32

The item quantity.

estimated_ship_date: Option<String>estimated_arrival_date: Option<String>per_unit_price: Option<Box<Money>>per_unit_tax: Option<Box<Money>>per_unit_declared_value: Option<Box<Money>>

Implementations

Item information for a fulfillment order.